@@ -8,13 +8,20 @@ import shutil, math, time
 
 # the system control class.
 class Logging(Object):
-	def __init__(self, database=None):
+	def __init__(self, attributes={}):
+
+		# docs.
+		DOCS = {
+			"module":"website.logging", 
+			"initialized":True,
+			"description":[], 
+			"chapter": "Logging", }
 
 		# defaults.
 		Object.__init__(self)
+		self.assign(attributes)
 		
 		# attributes.
-		self.database = database
 		if isinstance(self.database, (str,String,FilePath)):
 			self.database = Directory(str(self.database))
 
@@ -74,12 +81,22 @@ class Logging(Object):
 	class Alerts(Object):
 		def __init__(self, attributes={}):
 
+			# docs.
+			DOCS = {
+				"module":"website.logging.alerts", 
+				"initialized":True,
+				"description":[], 
+				"chapter": "Logging", }
+
 			# defaults.
 			Object.__init__(self)
 			self.assign(attributes)
 
 			# attributes.
-			self.alerts = Dictionary({}, path=self.database.join("logs/alerts"), default={})
+			if self.live:
+				self.alerts = Dictionary({}, path=self.database.join("logs/alerts"), default={})
+			else:
+				self.alerts = Dictionary({}, path=self.database.join("logs/alerts"))
 
 			#
 
